@@ -1,12 +1,12 @@
 package Test::WithDB;
 
-our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use DBI;
 use POSIX qw(strftime);
@@ -193,7 +193,7 @@ Test::WithDB - Framework for testing application using database
 
 =head1 VERSION
 
-This document describes version 0.05 of Test::WithDB (from Perl distribution Test-WithDB), released on 2015-04-22.
+This document describes version 0.06 of Test::WithDB (from Perl distribution Test-WithDB), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
